@@ -415,14 +415,33 @@ def ProcessBatch(sourcefolder, outputfolder,
     image_list = [x  for x in file_list if "jpg" or "JPG" or "JPEG" or "jpeg" in x]
     
     # -- Calibrate using first image
-    file = image_list[0]
-    df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
-                                     crop_method = crop_method, crop_param = crop_param, s = s, 
-                                     array_dimensions = array_dimensions, pin_size = pin_size,
-                                     features = features, adjust = adjust, rotate = rotate, 
-                                     save = False, display = True, calibrate = calibrate)
-    PP.DisplayTiles(tiles)
-    user_input = input("Would you like to proceed? y/n")
+    if calibrate:
+        if crop_param:
+            file = image_list[0]
+            df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                             crop_method = crop_method, crop_param = crop_param, s = s, 
+                                             array_dimensions = array_dimensions, pin_size = pin_size,
+                                             features = features, adjust = adjust, rotate = rotate, 
+                                             save = False, display = True, calibrate = False)
+            PP.DisplayTiles(tiles)
+            user_input = input("Would you like to proceed? y/n")
+        else:
+            file = image_list[0]
+            df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                             crop_method = crop_method, crop_param = crop_param, s = s, 
+                                             array_dimensions = array_dimensions, pin_size = pin_size,
+                                             features = features, adjust = adjust, rotate = rotate, 
+                                             save = False, display = True, calibrate = True)
+            PP.DisplayTiles(tiles)
+            user_input = input("Would you like to proceed? y/n")
+    else:
+        file = image_list[0]
+        df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                         crop_method = crop_method, crop_param = crop_param, s = s, 
+                                         array_dimensions = array_dimensions, pin_size = pin_size,
+                                         features = features, adjust = adjust, rotate = rotate, 
+                                         save = False, display = False, calibrate = calibrate)
+        user_input == 'y'
         
     # -- Process all images
     if user_input == 'y':
@@ -455,14 +474,26 @@ def ProcessBatch(sourcefolder, outputfolder,
         count = 0
         missed_images = []
         for file in image_list:
-            try:
-                Process1Image(file, sourcefolder, outputfolder,
+            if display:
+                try:
+                    print(file)
+                    Process1Image(file, sourcefolder, outputfolder,
+                     corners, s = s, array_dimensions = array_dimensions, pin_size = pin_size,
+                     features = features, adjust = adjust, rotate = rotate, save = True, display = True)
+                    count = count+1
+                except:
+                    missed_images.append(file)
+                    continue
+            else:
+                try:
+                    Process1Image(file, sourcefolder, outputfolder,
                      corners, s = s, array_dimensions = array_dimensions, pin_size = pin_size,
                      features = features, adjust = adjust, rotate = rotate, save = True, display = False)
-                count = count+1
-            except:
-                missed_images.append(file)
-                continue
+                    count = count+1
+                    print(file)
+                except:
+                    missed_images.append(file)
+                    continue
                 
         file_object = open(os.path.join(outputfolder,'BatchParameters.txt'), 'a')
         file_object.write(str(count)+' out of '+ str(len(file_list))+ ' images processed.')
@@ -636,14 +667,33 @@ def ParallelProcessBatch(sourcefolder, outputfolder, numThreads = 2,
     image_list = [x  for x in file_list if "jpg" or "JPG" or "JPEG" or "jpeg" in x]
     
     # -- Calibrate using first image
-    file = image_list[0]
-    df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
-                                     crop_method = crop_method, crop_param = crop_param, s = s, 
-                                     pin_size = pin_size, array_dimensions = array_dimensions,
-                                     adjust = adjust, rotate = rotate, features = featues,
-                                     save = False, display = True, calibrate = calibrate)
-    PP.DisplayTiles(tiles)
-    user_input = input("Would you like to proceed? y/n")
+    if calibrate:
+        if crop_param:
+            file = image_list[0]
+            df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                             crop_method = crop_method, crop_param = crop_param, s = s, 
+                                             array_dimensions = array_dimensions, pin_size = pin_size,
+                                             features = features, adjust = adjust, rotate = rotate, 
+                                             save = False, display = True, calibrate = False)
+            PP.DisplayTiles(tiles)
+            user_input = input("Would you like to proceed? y/n")
+        else:
+            file = image_list[0]
+            df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                             crop_method = crop_method, crop_param = crop_param, s = s, 
+                                             array_dimensions = array_dimensions, pin_size = pin_size,
+                                             features = features, adjust = adjust, rotate = rotate, 
+                                             save = False, display = True, calibrate = True)
+            PP.DisplayTiles(tiles)
+            user_input = input("Would you like to proceed? y/n")
+    else:
+        file = image_list[0]
+        df, tiles, masks, corners = ProcessImage(file, sourcefolder, outputfolder,
+                                         crop_method = crop_method, crop_param = crop_param, s = s, 
+                                         array_dimensions = array_dimensions, pin_size = pin_size,
+                                         features = features, adjust = adjust, rotate = rotate, 
+                                         save = False, display = False, calibrate = calibrate)
+        user_input == 'y'
         
     # -- Process all images
     if user_input == 'y':
